@@ -67,6 +67,28 @@ function m3ShowAdjustWindow(configId, serial)
 				"&_defconfig=" + configId + "&_defserial=" + serial,"",
 				"toolbar=no,menubar=no,location=no,status=no,scrollbars=yes,resizable=yes,width=1050,height=900");
 }
+// 各種端末用プレビューウィンドウ表示
+function m3ShowPreviewWindow(type, url)
+{
+	var width, height;
+	
+	switch (type){
+		case 0:		// PC用
+		default:
+			width = 1000;
+			height = 800;
+			break;
+		case 1:		// 携帯用
+			width = 200;
+			height = 500;
+			break;
+		case 2:		// スマートフォン用
+			width = 320;
+			height = 480;
+			break;
+	}
+	window.open(url, "", "toolbar=no,menubar=no,location=no,status=no,scrollbars=yes,resizable=yes,width=" + width + ",height=" + height);
+}
 /**
  * 画像ファイルブラウザを表示
  *
